/*****************************************************************************
 * Copyright (c) 2019, Nations Technologies Inc.
 *
 * All rights reserved.
 * ****************************************************************************
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Nations' name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY NATIONS "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL NATIONS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ****************************************************************************/

/**
 * @file hw_config.h
 * @author Nations
 * @version v1.0.0
 *
 * @copyright Copyright (c) 2019, Nations Technologies Inc. All rights reserved.
 */
#ifndef __HW_CONFIG_H__
#define __HW_CONFIG_H__

#include "n32l40x.h"
#include "usb_type.h"

/* Exported define -----------------------------------------------------------*/
#define SYSCLK_VALUE_48MHz            ((uint32_t)48000000)
#define SYSCLK_VALUE_72MHz            ((uint32_t)72000000)
#define SYSCLK_VALUE_96MHz            ((uint32_t)96000000)
#define SYSCLK_VALUE_108MHz           ((uint32_t)108000000)
#define PCLK2_VALUE_72MHz             ((uint32_t)72000000)
#define PCLK2_VALUE_48MHz             ((uint32_t)48000000)

#define OSC300_CTRL         ((__IO unsigned*)(0x40001824))

#define _DisOsc300Ldo()    (*OSC300_CTRL = (*OSC300_CTRL) | 0x800000);
#define _EnOsc300Ldo()     (*OSC300_CTRL = (*OSC300_CTRL) & (~0x800000));
#define _DisOsc300Core()   (*OSC300_CTRL = (*OSC300_CTRL) | 0x400000);
#define _EnOsc300Core()    (*OSC300_CTRL = (*OSC300_CTRL) & (~0x400000));
#define _DisOsc300Ibias()  (*OSC300_CTRL = (*OSC300_CTRL) | 0x1000000);
#define _EnOsc300Ibias()   (*OSC300_CTRL = (*OSC300_CTRL) & (~0x1000000));

#define KEY_PORT            GPIOA
#define KEY_PIN             GPIO_PIN_4


void Set_System(void);
ErrorStatus Set_USBClock(uint32_t sysclk);
void Enter_LowPowerMode(void);
void Leave_LowPowerMode(void);
void USB_Interrupts_Config(void);
void TimingDelay_Decrement(void);
void Delay(__IO uint32_t nCount);
void Cfg_KeyIO(void);
void USB_XtallessIni(uint32_t RCC_UCDR300MSource);
ErrorStatus USB_Config(uint32_t sysclk);



#endif /*__HW_CONFIG_H__*/

/**
 * @}
 */

/**
 * @}
 */

/**
 * @}
 */
